==> snipe-it-5.1.8.zip: snipe-it-5.1.8/resources/lang/ja/help.php <==
<?php

return array(

    /*
    |--------------------------------------------------------------------------
    | Password Reminder Language Lines
    |--------------------------------------------------------------------------
    |
    | The following language lines are the default lines which match reasons
    | that are given by the password broker for a password update attempt
    | has failed, such as for an invalid token or invalid new password.
    |
    */

    "more_info_title" => "詳細",

    "audit_help" => "Checking this box will edit the asset record to reflect this new location. Leaving it unchecked will simply note the location in the audit log.<br><br>Note that is this asset is checked out, it will not change the location of the person, asset or location it is checked out to.",

    'assets' => '資産はシリアル番号または資産タグで追跡されるアイテムです。特定のアイテムを識別することが重要なより高い価値のアイテムである傾向があります。',

    'categories' => 'カテゴリーはアイテムを整理するのに役立ちます。カテゴリーの例としては &quot;デスクトップ&quot;、&quot; ラップトップ&quot;、&quot； 携帯電話 &quot;、&quot; タブレット&quot; などがあります。資産カテゴリは任意に設定することができます。',

    'accessories' => 'Accessories are anything you issue to users but that do not have a serial number (or you do not care about tracking them uniquely). For example, computer mice or keyboards.',

    'companies'     => '会社フィールドは単純な識別子フィールドとして使用することができます。また、資産、ユーザーなどの権限を制限する設定も管理者が設定できます。',

    'components'    => '構成部品名は 資産の一部となるアイテムです。(例 HDD, RAM など)',

    'consumables'   => '消耗品は、時間の経過とともに使用されるものです。例えば、プリンタインクやコピー用紙など。',

    'depreciations' => '定額法に基づいて資産の減価償却を設定することができます。',



);

==> snipe-it-5.4.3.zip: snipe-it-5.4.3/resources/lang/ja/help.php <==
<?php

return [

    /*
    |--------------------------------------------------------------------------
    | Password Reminder Language Lines
    |--------------------------------------------------------------------------
    |
    | The following language lines are the default lines which match reasons
    | that are given by the password broker for a password update attempt
    | has failed, such as for an invalid token or invalid new password.
    |
    */

    'more_info_title' => '詳細',

    'audit_help' => 'Checking this box will edit the asset record to reflect this new location. Leaving it unchecked will simply note the location in the audit log.<br><br>Note that is this asset is checked out, it will not change the location of the person, asset or location it is checked out to.',

    'assets' => '資産はシリアル番号または資産タグで追跡されるアイテムです。特定のアイテムを識別することが重要なより高い価値のアイテムである傾向があります。',

    'categories' => 'カテゴリーはアイテムを整理するのに役立ちます。カテゴリーの例としては &quot;デスクトップ&quot;、&quot; ラップトップ&quot;、&quot； 携帯電話 &quot;、&quot; タブレット&quot; などがあります。資産カテゴリは任意に設定することができます。',

    'accessories' => 'Accessories are anything you issue to users but that do not have a serial number (or you do not care about tracking them uniquely). For example, computer mice or keyboards.',

    'companies'     => '会社フィールドは単純な識別子フィールドとして使用することができます。また、資産、ユーザーなどの権限を制限する設定も管理者が設定できます。',

    'components'    => '構成部品名は 資産の一部となるアイテムです。(例 HDD, RAM など)',

    'consumables'   => '消耗品は、時間の経過とともに使用されるものです。例えば、プリンタインクやコピー用紙など。',

    'depreciations' => '定額法に基づいて資産の減価償却を設定することができます。',

];
